@@ -38,7 +38,8 @@ use std::fs::set_permissions;
 use std::os::unix::fs::{MetadataExt, PermissionsExt};
 
 // Locals
-use crate::fs::{FsDirectory, FsEntry, FsFile};
+use crate::fs::{FsDirectory, FsEntry, FsFile, UnixPex};
+use crate::utils::path;
 
 /// ## HostErrorType
 ///
@@ -461,7 +462,6 @@ impl Localhost {
                 last_change_time: attr.modified().unwrap_or(SystemTime::UNIX_EPOCH),
                 last_access_time: attr.accessed().unwrap_or(SystemTime::UNIX_EPOCH),
                 creation_time: attr.created().unwrap_or(SystemTime::UNIX_EPOCH),
-                readonly: attr.permissions().readonly(),
                 symlink: match fs::read_link(path.as_path()) {
                     Ok(p) => match self.stat(p.as_path()) {
                         Ok(entry) => Some(Box::new(entry)),
@@ -484,7 +484,6 @@ impl Localhost {
                     last_change_time: attr.modified().unwrap_or(SystemTime::UNIX_EPOCH),
                     last_access_time: attr.accessed().unwrap_or(SystemTime::UNIX_EPOCH),
                     creation_time: attr.created().unwrap_or(SystemTime::UNIX_EPOCH),
-                    readonly: attr.permissions().readonly(),
                     size: attr.len() as usize,
                     ftype: extension,
                     symlink: match fs::read_link(path.as_path()) {
@@ -506,7 +505,6 @@ impl Localhost {
     ///
     /// Stat file and create a FsEntry
     #[cfg(target_os = "windows")]
-    #[cfg(not(tarpaulin_include))]
     pub fn stat(&self, path: &Path) -> Result<FsEntry, HostError> {
         let path: PathBuf = self.to_abs_path(path);
         info!("Stating file {}", path.display());
@@ -530,7 +528,6 @@ impl Localhost {
                 last_change_time: attr.modified().unwrap_or(SystemTime::UNIX_EPOCH),
                 last_access_time: attr.accessed().unwrap_or(SystemTime::UNIX_EPOCH),
                 creation_time: attr.created().unwrap_or(SystemTime::UNIX_EPOCH),
-                readonly: attr.permissions().readonly(),
                 symlink: match fs::read_link(path.as_path()) {
                     Ok(p) => match self.stat(p.as_path()) {
                         Ok(entry) => Some(Box::new(entry)),
@@ -554,7 +551,6 @@ impl Localhost {
                     last_change_time: attr.modified().unwrap_or(SystemTime::UNIX_EPOCH),
                     last_access_time: attr.accessed().unwrap_or(SystemTime::UNIX_EPOCH),
                     creation_time: attr.created().unwrap_or(SystemTime::UNIX_EPOCH),
-                    readonly: attr.permissions().readonly(),
                     size: attr.len() as usize,
                     ftype: extension,
                     symlink: match fs::read_link(path.as_path()) {
@@ -789,10 +785,10 @@ impl Localhost {
     ///
     /// Return string with format xxxxxx to tuple of permissions (user, group, others)
     #[cfg(target_family = "unix")]
-    fn u32_to_mode(&self, mode: u32) -> (u8, u8, u8) {
-        let user: u8 = ((mode >> 6) & 0x7) as u8;
-        let group: u8 = ((mode >> 3) & 0x7) as u8;
-        let others: u8 = (mode & 0x7) as u8;
+    fn u32_to_mode(&self, mode: u32) -> (UnixPex, UnixPex, UnixPex) {
+        let user: UnixPex = UnixPex::from(((mode >> 6) & 0x7) as u8);
+        let group: UnixPex = UnixPex::from(((mode >> 3) & 0x7) as u8);
+        let others: UnixPex = UnixPex::from((mode & 0x7) as u8);
         (user, group, others)
     }
 
@@ -808,15 +804,7 @@ impl Localhost {
     ///
     /// Convert path to absolute path
     fn to_abs_path(&self, p: &Path) -> PathBuf {
-        // Convert to abs path
-        match p.is_relative() {
-            true => {
-                let mut path: PathBuf = self.wrkdir.clone();
-                path.push(p);
-                path
-            }
-            false => PathBuf::from(p),
-        }
+        path::absolutize(self.wrkdir.as_path(), p)
     }
 }
 
