@@ -29,6 +29,7 @@
 pub mod bookmarks_client;
 pub mod config_client;
 pub mod environment;
-pub(crate) mod keys;
+pub(self) mod keys;
 pub mod logging;
 pub mod sshkey_storage;
+pub mod theme_provider;
