@@ -25,7 +25,7 @@
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
  */
-use crate::fs::{FsDirectory, FsEntry, FsFile};
+use crate::fs::{FsDirectory, FsEntry, FsFile, UnixPex};
 // ext
 use std::fs::File;
 #[cfg(feature = "with-containers")]
@@ -53,12 +53,11 @@ pub fn create_sample_file_entry() -> (FsFile, NamedTempFile) {
             last_access_time: SystemTime::UNIX_EPOCH,
             creation_time: SystemTime::UNIX_EPOCH,
             size: 127,
-            ftype: None, // File type
-            readonly: false,
-            symlink: None,             // UNIX only
-            user: Some(0),             // UNIX only
-            group: Some(0),            // UNIX only
-            unix_pex: Some((6, 4, 4)), // UNIX only
+            ftype: None,    // File type
+            symlink: None,  // UNIX only
+            user: Some(0),  // UNIX only
+            group: Some(0), // UNIX only
+            unix_pex: Some((UnixPex::from(6), UnixPex::from(4), UnixPex::from(4))), // UNIX only
         },
         tmpfile,
     )
@@ -162,11 +161,10 @@ pub fn make_fsentry(path: PathBuf, is_dir: bool) -> FsEntry {
             last_change_time: SystemTime::UNIX_EPOCH,
             last_access_time: SystemTime::UNIX_EPOCH,
             creation_time: SystemTime::UNIX_EPOCH,
-            readonly: false,
-            symlink: None,             // UNIX only
-            user: Some(0),             // UNIX only
-            group: Some(0),            // UNIX only
-            unix_pex: Some((6, 4, 4)), // UNIX only
+            symlink: None,  // UNIX only
+            user: Some(0),  // UNIX only
+            group: Some(0), // UNIX only
+            unix_pex: Some((UnixPex::from(6), UnixPex::from(4), UnixPex::from(4))), // UNIX only
         }),
         false => FsEntry::File(FsFile {
             name: path.file_name().unwrap().to_string_lossy().to_string(),
@@ -175,12 +173,11 @@ pub fn make_fsentry(path: PathBuf, is_dir: bool) -> FsEntry {
             last_access_time: SystemTime::UNIX_EPOCH,
             creation_time: SystemTime::UNIX_EPOCH,
             size: 127,
-            ftype: None, // File type
-            readonly: false,
-            symlink: None,             // UNIX only
-            user: Some(0),             // UNIX only
-            group: Some(0),            // UNIX only
-            unix_pex: Some((6, 4, 4)), // UNIX only
+            ftype: None,    // File type
+            symlink: None,  // UNIX only
+            user: Some(0),  // UNIX only
+            group: Some(0), // UNIX only
+            unix_pex: Some((UnixPex::from(6), UnixPex::from(4), UnixPex::from(4))), // UNIX only
         }),
     }
 }
@@ -200,7 +197,7 @@ mod test {
     #[test]
     fn test_utils_test_helpers_sample_file() {
         let (file, _) = create_sample_file_entry();
-        assert_eq!(file.readonly, false);
+        assert!(file.symlink.is_none());
     }
 
     #[test]
